@@ -296,8 +296,10 @@ function (S, G, n, form, datsp, tol = 0.1)
     
     first.fit <- list(x = model.matrix(as.formula(form), data = datsp)[, 
         -1], y = datsp$obs, offset=offset, formula = form)
-    if (tol < 0 || tol >= 1) 
-        stop("Minimum Prevalence % must be between 0 and 1")
+    if(class(first.fit$x)=="numeric") {first.fit$x <- matrix(first.fit$x,length(first.fit$x),1) }#deal with model matrix returning a vector for covar == 1
+
+    if (tol < 0 || tol >= 1)
+      stop("Minimum Prevalence % must be between 0 and 1")
     sp.name <- 1:S
     sp <- rep(sp.name, each = n)
     starting.fitem <- list(intercepts = rep(0, S), alpha = rep(0, 
@@ -389,6 +391,7 @@ function (S, G, n, form, datsp, tol = 0.1)
     if(is.null(offset)) offset <- rep(0,nrow(MM))
     first.fit <- list(x = model.matrix(as.formula(form), data = datsp)[, 
         -1], y = datsp$obs, offset=offset,formula = form)
+     if(class(first.fit$x)=="numeric") {first.fit$x <- matrix(first.fit$x,length(first.fit$x),1) }#deal with model matrix returning a vector for covar == 1
     if (tol < 0 || tol >= 1) 
         stop("Minimum Prevalence % must be between 0 and 1")
     sp.name <- 1:S
@@ -1846,7 +1849,7 @@ function (object,new.obs,...)
     X <- cbind(model.matrix(model.fm,new.obs),1)
     offset <- model.frame(model.fm, data = new.obs)
     offset <- model.offset(offset)
-    if(is.null(offset)) offset <-  rep(0,row(X))
+    if(is.null(offset)) offset <-  rep(0,nrow(X))
 
     outvar <- matrix(NA,dim(X)[1],G)
     outpred <- matrix(NA,dim(X)[1],G)
@@ -2576,242 +2579,3 @@ function (g, first.fit, tau, n, fmM, sp)
         sp.intercept = fmM[[g]]$sp.intercept, fitted = f.mix$fitted))
 }
 
-# MVB's workaround for futile CRAN 'no visible blah' check:
-globalVariables( package="SpeciesMix",
-  names=c( ".Traceback"
-    ,"inv"
-    ,"x"
-    ,"x.t"
-    ,"dat.tau"
-    ,"tau"
-    ,"i"
-    ,"n"
-    ,"form"
-    ,"datsp"
-    ,"y"
-    ,"obs"
-    ,"f.mix"
-    ,"sp.int"
-    ,"theta"
-    ,"X"
-    ,"data"
-    ,"out"
-    ,"S"
-    ,"k"
-    ,"group"
-    ,"s"
-    ,"g"
-    ,"lgtp"
-    ,"p"
-    ,"tmp"
-    ,"my.fun"
-    ,"sp.data"
-    ,"covar.data"
-    ,"em.prefit"
-    ,"em.steps"
-    ,"em.refit"
-    ,"est.var"
-    ,"G"
-    ,"sp.form"
-    ,"aic"
-    ,"bic"
-    ,"fm"
-    ,"logl"
-    ,"covar"
-    ,"fmM"
-    ,"first.fit"
-    ,"MM"
-    ,"tol"
-    ,"sp.name"
-    ,"sp"
-    ,"starting.fitem"
-    ,"all.betas"
-    ,"j"
-    ,"fit"
-    ,"sp.intercepts"
-    ,"fmmvnorm"
-    ,"centers"
-    ,"B"
-    ,"cluster"
-    ,"est.tau"
-    ,"max.newTau"
-    ,"alpha"
-    ,"newTau"
-    ,"phi"
-    ,"new.dist"
-    ,"old.dist"
-    ,"ii"
-    ,"jj"
-    ,"mu.N"
-    ,"lambda"
-    ,"mu.Z"
-    ,"res"
-    ,"LOG"
-    ,"do.checks"
-    ,"mu"
-    ,"dens"
-    ,"tmp.like"
-    ,"sel.sp"
-    ,"spname"
-    ,"link.fun"
-    ,"lpre"
-    ,"linkinv"
-    ,"eps"
-    ,"sum.like"
-    ,"temp.warn"
-    ,"ite"
-    ,"logL"
-    ,"old.logL"
-    ,"t1"
-    ,"ite.max"
-    ,"fm.out"
-    ,"EN"
-    ,"d"
-    ,"t.pi"
-    ,"parms"
-    ,"logL.full"
-    ,"full.model"
-    ,"pars"
-    ,"gradient"
-    ,"model.type"
-    ,"loglike"
-    ,"calc.deriv"
-    ,"ll"
-    ,"hes"
-    ,"calc.hes"
-    ,"r.logl"
-    ,"int.out"
-    ,"fm.theta"
-    ,"sp.intercept"
-    ,"sp.dispersion"
-    ,"r.deriv"
-    ,"fm.phi"
-    ,"fm.p"
-    ,"sp.phi"
-    ,"sp.p"
-    ,"pars.og"
-    ,"mustart"
-    ,"se"
-    ,"X.p"
-    ,"offsetty"
-    ,"wts"
-    ,"p.flag"
-    ,"phi.flag"
-    ,"dTweedparms"
-    ,"DTweedparmsDmu"
-    ,"derivs"
-    ,"DTweedparmsDphi"
-    ,"tmpPhi"
-    ,"dalphadp"
-    ,"DTweedparmsDp"
-    ,"tmpP"
-    ,"like"
-    ,"lf"
-    ,"lg"
-    ,"dBi"
-    ,"dl.dpi"
-    ,"der"
-    ,"dpi.deta"
-    ,"ad.trans"
-    ,"d1"
-    ,"var.names"
-    ,"log.like"
-    ,"out.tau"
-    ,"PIT"
-    ,"t.obs"
-    ,"pre"
-    ,"dis"
-    ,"nSucc"
-    ,"transfo"
-    ,"D.n"
-    ,"x0"
-    ,"m"
-    ,"D.f0"
-    ,"f"
-    ,"..."
-    ,"D.accur"
-    ,"D.w"
-    ,"D.co"
-    ,"D.n.c"
-    ,"macheps"
-    ,"double.eps"
-    ,"D.h"
-    ,"D.deriv"
-    ,"D.temp.f"
-    ,"D.xd"
-    ,"H.n"
-    ,"d.x0"
-    ,"fun"
-    ,"accur"
-    ,"Hes"
-    ,"type"
-    ,"H.h"
-    ,"H.f0"
-    ,"H.m"
-    ,"H.w"
-    ,"H.co"
-    ,"H.n.c"
-    ,"Hes.diag"
-    ,"H.temp.f"
-    ,"H.xd"
-    ,"dll.path"
-    ,"libname"
-    ,"pkgname"
-    ,"subarch"
-    ,"r_arch"
-    ,"this.ext"
-    ,"dynlib.ext"
-    ,"dlls"
-    ,"mixture.model"
-    ,"object"
-    ,"model.fm"
-    ,"new.obs"
-    ,"outvar"
-    ,"outpred"
-    ,"lp"
-    ,"dhdB"
-    ,"c2"
-    ,"s.outvar"
-    ,"s.outpred"
-    ,"ps"
-    ,"np"
-    ,"rans"
-    ,"t.covar.data"
-    ,"t.sp.data"
-    ,"."
-    ,"prefit"
-    ,"r1"
-    ,"fmM.out"
-    ,"fun.est.var"
-    ,"e"
-    ,"mean.form"
-    ,"temp.p"
-    ,"offset.p"
-    ,"wts1"
-    ,"fm1"
-    ,"inits"
-    ,"abit"
-    ,"ystar"
-    ,"ptemp"
-    ,"disDev"
-    ,"disPear"
-    ,"fmTGLM"
-    ,"iter.max"
-    ,"my.lower"
-    ,"my.upper"
-    ,"par"
-    ,"vcovar"
-    ,"scores"
-    ,"phi1"
-    ,"p1"
-    ,"resids"
-    ,"nzero"
-    ,"ICadj"
-    ,"objective"
-    ,"convergence"
-    ,"iterations"
-    ,"evaluations"
-    ,"sp.mat"
-    ,"sp.int.offset"
-))
-
